@@ -64,7 +64,7 @@ enum {
 	PROP_NAME,
 	PROP_TITLE,
 	PROP_ICON,
-	PROP_LOCK_BUTTON
+	PROP_SHOW_LOCK_BUTTON
 };
 
 typedef struct _GstAsyncData {
@@ -111,10 +111,10 @@ gst_tool_class_init (GstToolClass *class)
 							      G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 
 	g_object_class_install_property (object_class,
-					 PROP_LOCK_BUTTON,
-					 g_param_spec_boolean ("lock_button",
-					                       "Lock button",
-					                       "Show PolkitLockButton",
+					 PROP_SHOW_LOCK_BUTTON,
+					 g_param_spec_boolean ("show_lock_button",
+					                       "Show lock button",
+					                       "Whether to show lock button",
 					                       TRUE,
 					                       G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 }
@@ -237,7 +237,7 @@ gst_tool_constructor (GType                  type,
 		tool->ui_path = g_strdup_printf (INTERFACES_DIR "/%s.ui", tool->name);
 
 		widget_name = g_strdup_printf ("%s_admin", tool->name);
-		tool->main_dialog = gst_dialog_new (tool, widget_name, tool->title, tool->lock_button);
+		tool->main_dialog = gst_dialog_new (tool, widget_name, tool->title, tool->show_lock_button);
 		g_free (widget_name);
 	}
 
@@ -275,8 +275,8 @@ gst_tool_set_property (GObject      *object,
 	case PROP_ICON:
 		tool->icon = g_value_dup_string (value);
 		break;
-	case PROP_LOCK_BUTTON:
-		tool->lock_button = g_value_get_boolean (value);
+	case PROP_SHOW_LOCK_BUTTON:
+		tool->show_lock_button = g_value_get_boolean (value);
 		break;
 	}
 }
